facebook-ads-api
================

Python client for the [Facebook Ads API](https://developers.facebook.com/docs/ads-api/).


Installation
------------
pip install facebook-ads-api

Usage
-----

    import facebook

    api = facebook.AdsAPI(access_token, app_id, app_secret)
